@@ -8,12 +8,15 @@ use warnings;
 use Carp;
 use base qw{ Exporter };
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our @EXPORT_OK = qw{
+    MINIMUM_PERL
     VARIABLE_RE
 };
 
+use constant MINIMUM_PERL	=> '5.000';
+
 # Match the name of a variable. The user of this needs to anchor it
 # right after the sigil. The line noise is [[:punct:]] as documented in
 # perlrecharclass, less anything that needs to be excluded (currently
@@ -50,6 +53,12 @@ default.
 
 The following importable constants are provided:
 
+=head2 MINIMUM_PERL
+
+The minimum version of Perl understood by this parser, as a string. It
+is currently set to C<'5.000'>, since that is the minimum version of
+Perl accessible to the author.
+
 =head2 VARIABLE_RE
 
 This constant is a regular expression object that matches Perl variable
