@@ -6,26 +6,19 @@ use strict;
 use warnings;
 
 use Carp;
-use PPI::Document;
 use PPIx::QuoteLike;
-use PPIx::QuoteLike::Constant qw{ @CARP_NOT };
-use PPIx::QuoteLike::Utils qw{ __instance };
 use Scalar::Util ();
 
-our $VERSION = '0.022_01';
-
-use constant SCALAR_REF	=> ref \0;
+our $VERSION = '0.003';
 
 {
     my $default = {
 	encoding	=> undef,
 	file		=> undef,
 	indent		=> 2,
-	locations	=> 0,
 	margin		=> 0,
 	perl_version	=> 0,
 	ppi		=> 0,
-	short		=> 0,
 	significant	=> 0,
 	tokens		=> 0,
 	variables	=> 0,
@@ -47,11 +40,7 @@ use constant SCALAR_REF	=> ref \0;
 
 	$self->{object} = _isa( $source, 'PPIx::QuoteLike' ) ? $source :
 	    PPIx::QuoteLike->new( $source,
-		__instance( $source, 'PPI::Element' ) ? () : (
-		    location	=> [ 1, 1, 1, 1, -f $source ? $source :
-			undef ],
-		),
-		map { $_ => $arg{$_} } qw{ encoding },
+		map { $_ => $arg{$_} } qw{ encoding postderef },
 	    )
 	    or return;
 
@@ -62,11 +51,9 @@ use constant SCALAR_REF	=> ref \0;
 sub dump : method {	## no critic (ProhibitBuiltinHomonyms)
     my ( $class, $source, %arg ) = @_;
     my $rslt;
-    my $margin = ' ' x ( $arg{margin} || 0 );
-    my $none = delete $arg{none};
     foreach my $obj ( $class->_source_to_dumpers( $source, %arg ) ) {
 	my $src = $obj->{object}->source();
-	$rslt .= "\n$margin$src";
+	$rslt .= "\n$src";
 	if ( _isa( $src, 'PPI::Element' ) and my $loc = $src->location() ) {
 	    $rslt .= sprintf ' %s line %d column %d',
 		_dor( $loc->[4], $obj->{file}, '?' ),
@@ -76,14 +63,13 @@ sub dump : method {	## no critic (ProhibitBuiltinHomonyms)
     }
     defined $rslt
 	and return $rslt;
-    defined $none
-	or return;
-    $none =~ s/ (?: \A | (?<! \n ) ) \z /\n/smx;
-    return $none;
+    return;
 }
 
 sub list {
-    my ( $self ) = @_;
+    my ( $self, $split ) = @_;
+    __PACKAGE__ eq caller	# Only this package is allowed to
+	or $split = undef;	# set the $split argument.
     my $indent;
     my $obj = $self->{object};
     my @rslt;
@@ -99,49 +85,24 @@ sub list {
 	    map { _format_content( $obj, $_ ) }
 	    qw{ type start finish };
 	push @rslt,
-	    join "\t", $self->_class_name( $obj ), $string,
-	    _format_attr( $obj, qw{ encoding failures interpolates
-		indentation } ),
+	    join "\t", ref $obj, $string,
+	    _format_attr( $obj, qw{ failures interpolates } ),
 	    $self->_perl_version( $obj ),
 	    $self->_variables( $obj ),
 	    ;
 	$selector = sub { return $obj->children() };
     }
     foreach my $elem ( $selector->() ) {
-	$self->{significant}
-	    and not $elem->significant()
-	    and next;
-	my $locn = $self->{locations} ?
-	    __instance( $elem, 'PPIx::QuoteLike::Token' ) ?
-		sprintf '[ % 4d, % 3d, % 3d ] ',
-		    $elem->logical_line_number(),
-		    $elem->column_number(),
-		    $elem->visual_column_number() :
-		' ' x 19 :
-	    '';
 	my @line = (
-	    $self->_class_name( $elem ),
+	    ref $elem,
 	    _quote( $elem->content() ),
 	    $self->_perl_version( $elem ),
 	    $self->_variables( $elem ),
 	);
 	my @ppi;
-	@ppi = $self->_ppi( $elem )
-	    and shift @ppi;	# Ignore PPI::Document
-	foreach ( @ppi ) {
-	    if ( $self->{locations} ) {
-		s/ ( [0-9]+ \s+ \] ) /$1  /smxg
-		    or substr $_, 0, 0, '  ';
-	    } else {
-		substr $_, 0, 0, '  ';
-	    }
-	}
-	my $leader = "$locn$indent";
-	foreach ( join( "\t", @line ), @ppi ) {
-	    push @rslt, "$leader$_";
-	    # $locn = $self->{locations} ? ' ' x 19 : '';
-	    $leader = '';
-	}
+	@ppi = $self->_ppi( $elem, $split )
+	    and push @line, shift @ppi;
+	push @rslt, map { "$indent$_" } join( "\t", @line ), @ppi;
     }
     return @rslt;
 }
@@ -155,15 +116,7 @@ sub print : method {	## no critic (ProhibitBuiltinHomonyms)
 sub string {
     my ( $self ) = @_;
     my $margin = ' ' x $self->{margin};
-    return join '', map { "$margin$_\n" } $self->list();
-}
-
-sub _class_name {
-    my ( $self, $obj ) = @_;
-    my $class = ref $obj;
-    $self->{short}
-	and $class =~ s/ \A PPIx::QuoteLike:: //smx;
-    return $class;
+    return join '', map { "$margin$_\n" } $self->list( 1 );
 }
 
 {
@@ -175,10 +128,12 @@ sub _class_name {
 
     sub _doc_to_dumper {
 	my ( $class, $path, %arg ) = @_;
+	require PPI::Document;
 	$doc = PPI::Document->new( $path )
 	    or return;
 	ref $path
 	    or $arg{file} = $path;
+	$doc->index_locations();
 	return map { $class->new( $_, %arg ) }
 	    @{ $doc->find( 'PPI::Token' ) || [] };
     }
@@ -206,11 +161,10 @@ sub _format_attr {
 
 sub _format_content {
     my ( $obj, $method, @arg ) = @_;
-    my @val = map { $_->content() }
-	    grep { $_->significant() }
-	    $obj->$method( @arg )
-	or return '?';
-    return join '', @val;
+    my $val = $obj->$method( @arg );
+    ref $val
+	and $val = $val->content();
+    return defined $val ? $val : '?';
 }
 
 sub _isa {
@@ -230,29 +184,24 @@ sub _perl_version {
 }
 
 sub _ppi {
-    my ( $self, $elem ) = @_;
+    my ( $self, $elem, $split ) = @_;
 
     $self->{ppi}
 	and $elem->can( 'ppi' )
 	or return;
 
     require PPI::Dumper;
-
-    # PPI::Dumper reports line_number(), but I want
-    # logical_line_number(). There is no configuration for this, but the
-    # interface is public, so I mung it to do what I want.
-    my $locn = PPI::Element->can( 'location' );
-    local *PPI::Element::location = sub {
-	my $loc = $locn->( @_ );
-	$loc->[0] = $loc->[3];
-	return $loc;
-    };
-
     my $dumper = PPI::Dumper->new( $elem->ppi(),
-	map { $_ => $self->{$_} } qw{ indent locations },
+	map { $_ => $self->{$_} } qw{ indent },
     );
 
-    return $dumper->list();
+    my $str = $dumper->string();
+    chomp $str;
+
+    $split
+	and return split qr{ \n }smx, $str;
+
+    return $str;
 }
 
 sub _quote {
@@ -271,6 +220,17 @@ __END_OF_HERE_DOCUMENT
 ";
     }
 
+=begin comment
+
+    $val =~ m/ [{}] /smx
+	or return "q{$val}";
+    $val =~ m{ / }smx
+	or return "q/$val/";
+
+=end comment
+
+=cut
+
     $val =~ s/ (?= [\\'] )/\\/smxg;
     return "'$val'";
 }
@@ -288,7 +248,7 @@ sub _source_to_dumpers {
 		and return $class->new( $path, %arg );
 	}
     } elsif ( my $ref = ref $path ) {
-	SCALAR_REF eq $ref
+	'SCALAR' eq $ref
 	    or return;
 	return $class->_doc_to_dumper( $path, %arg );
     } else {
@@ -314,12 +274,10 @@ sub _variables {
     my ( $self, $elem ) = @_;
 
     $self->{variables}
+	and $elem->can( 'variables' )
 	or return;
 
-    my @var = $elem->variables()
-	or return;
-
-    return join ',', sort @var;
+    return join ',', sort $elem->variables();
 }
 
 1;
@@ -332,7 +290,7 @@ PPIx::QuoteLike::Dumper - Dump the results of parsing quotelike things
 
 =head1 SYNOPSIS
 
- use PPIx::QuoteLike::Dumper;
+ use PPI::QuoteLike::Dumper;
  PPIx::QuoteLike::Dumper->new( '"foo$bar baz"' )
    ->print();
 
@@ -394,10 +352,6 @@ The default is C<0> (i.e. false).
 
 =item postderef Boolean
 
-B<THIS ARGUMENT IS DEPRECATED>.  See L<DEPRECATION
-NOTICE|PPIx::QuoteLike/DEPRECATION NOTICE> in
-L<PPIx::QuoteLike|PPIx::QuoteLike> for the details.
-
 This argument specifies whether or not postfix dereferences are
 recognized in interpolations. It is passed through to
 L<PPIx::QuoteLike|PPIx::QuoteLike> L<new()|PPIx::QuoteLike/new> unless
@@ -411,11 +365,6 @@ interpolations.
 
 The default is C<0> (i.e. false).
 
-=item short Boolean
-
-If true, leading C<'PPIx::QuoteLike::'> will be removed from the class
-names in the output.
-
 =item tokens boolean
 
 If true, this argument causes an unstructured dump of tokens found in
@@ -458,22 +407,6 @@ L<PPI::Node|PPI::Node>.
 Otherwise the first argument is handled just like L<new()|/new> would
 handle it.
 
-The return is the string representation of the dump.
-
-In addition to the optional arguments accepted by L<new()|/new>, the
-following can be specified:
-
-=over
-
-=item none
-
-This argument specifies a string to return if no dump can be produced
-(typically because the first argument is neither a file name nor text
-that is recognized by this package). If unspecified, or specified as
-C<undef>, nothing is returned in this case.
-
-=back 
-
 The output for an individual quote-like object differs from the
 L<string()|/string> output on the same object in that it is preceded by
 the literal sting being dumped, and file and location information if
@@ -494,6 +427,14 @@ specified when the dumper was instantiated.
 
 This method simply prints the result of L</string> to standard out.
 
+=cut
+
+sub print : method {	## no critic (ProhibitBuiltinHomonyms)
+    my ( $self ) = @_;
+    print $self->string();
+    return;
+}
+
 =head2 string
 
  print $dumper->string();
@@ -506,9 +447,7 @@ concatenates the result into a single string, and returns that string.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=PPIx-QuoteLike>,
-L<https://github.com/trwyant/perl-PPIx-QuoteLike/issues>, or in
-electronic mail to the author.
+L<http://rt.cpan.org>, or in electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -516,7 +455,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2022 by Thomas R. Wyant, III
+Copyright (C) 2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
