@@ -6,8 +6,9 @@ use strict;
 use warnings;
 
 use Carp;
+use PPIx::QuoteLike::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 # Private to this package.
 sub __new {
@@ -39,6 +40,25 @@ sub next_sibling {
     return $self->{next_sibling};
 }
 
+sub perl_version_introduced {
+    my ( $self ) = @_;
+    # TODO use '//' when we can require Perl 5.10.
+    defined $self->{perl_version_introduced}
+	and return $self->{perl_version_introduced};
+    my $vers = $self->__perl_version_introduced();
+    defined $vers
+	or $vers = MINIMUM_PERL;
+    return ( $self->{perl_version_introduced} = $vers );
+}
+
+sub __perl_version_introduced {
+    return;
+}
+
+sub perl_version_removed {
+    return undef;	## no critic (ProhibitExplicitReturnUndef)
+}
+
 sub previous_sibling {
     my ( $self ) = @_;
     $self->{previous_sibling}
@@ -115,6 +135,32 @@ L<PPIx::QuoteLike|PPIx::QuoteLike> object that contains it.
 This method returns the token after the invocant, or nothing if there is
 none.
 
+=head2 perl_version_introduced
+
+This method returns the version of Perl in which the element was
+introduced. This will be at least 5.000. Before 5.006 I am relying on
+the F<perldelta>, F<perlre>, and F<perlop> documentation, since I have
+been unable to build earlier Perls. Since I have found no documentation
+before 5.003, I assume that anything found in 5.003 is also in 5.000.
+
+Since this all depends on my ability to read and understand masses of
+documentation, the results of this method should be viewed with caution,
+if not downright skepticism.
+
+There are also cases which are ambiguous in various ways. For those see
+L<PPIx::Regexp/RESTRICTIONS>, and especially
+L<PPIx::Regexp/Changes in Syntax>.
+
+=head2 perl_version_removed
+
+This method returns the version of Perl in which the element was
+removed. If the element is still valid the return is C<undef>.
+
+All the I<caveats> to
+L<perl_version_introduced()|/perl_version_introduced> apply here also,
+though perhaps less severely since although many features have been
+introduced since 5.0, few have been removed.
+
 =head2 previous_sibling
 
  my $prev = $token->previous_sibling();
